@@ -7,25 +7,23 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 mod chunk_storage;
-mod reading;
-mod writing;
 
 use crate::{
-    node_ops::{NodeDuties, NodeDuty},
+    error::convert_to_error_message,
+    node_ops::{NodeDuties, NodeDuty, OutgoingMsg},
     Result,
 };
 use chunk_storage::ChunkStorage;
 use log::info;
 use sn_data_types::{Blob, BlobAddress};
 use sn_messaging::{
-    client::{BlobRead, BlobWrite},
-    EndUser, MessageId,
+    client::{BlobRead, BlobWrite, CmdError, Message, NodeEvent},
+    Aggregation, DstLocation, EndUser, MessageId,
 };
 use std::{
     fmt::{self, Display, Formatter},
     path::Path,
 };
-use xor_name::XorName;
 
 /// At 50% full, the node will report that it's reaching full capacity.
 pub const MAX_STORAGE_USAGE_RATIO: f64 = 0.5;
@@ -42,8 +40,21 @@ impl Chunks {
         })
     }
 
-    pub async fn read(&mut self, read: &BlobRead, msg_id: MessageId) -> Result<NodeDuties> {
-        reading::get_result(read, msg_id, &self.chunk_storage).await
+    pub fn keys(&self) -> Vec<BlobAddress> {
+        self.chunk_storage.keys()
+    }
+
+    pub async fn remove_chunk(&mut self, address: &BlobAddress) -> Result<()> {
+        self.chunk_storage.delete_chunk(address).await
+    }
+
+    pub fn get_chunk(&self, address: &BlobAddress) -> Result<Blob> {
+        self.chunk_storage.get_chunk(address)
+    }
+
+    pub fn read(&mut self, read: &BlobRead, msg_id: MessageId) -> NodeDuties {
+        let BlobRead::Get(address) = read;
+        self.chunk_storage.get(address, msg_id)
     }
 
     pub async fn write(
@@ -52,7 +63,13 @@ impl Chunks {
         msg_id: MessageId,
         origin: EndUser,
     ) -> Result<NodeDuty> {
-        writing::get_result(write, msg_id, origin, &mut self.chunk_storage).await
+        match &write {
+            BlobWrite::New(data) => self.chunk_storage.store(&data, msg_id).await,
+            // really though, for a delete, what we should be looking at is the origin signature! That would be the source of truth!
+            BlobWrite::DeletePrivate(address) => {
+                self.chunk_storage.delete(*address, msg_id, origin).await
+            }
+        }
     }
 
     pub async fn check_storage(&self) -> Result<NodeDuties> {
@@ -64,22 +81,28 @@ impl Chunks {
         }
     }
 
-    /// Returns a chunk to the Elders of a section.
-    pub async fn get_chunk_for_replication(
-        &self,
-        address: BlobAddress,
-        msg_id: MessageId,
-        section: XorName,
-    ) -> Result<NodeDuty> {
-        info!("Send blob for replication to the Elders.");
-        self.chunk_storage
-            .get_for_replication(address, msg_id, section)
-            .await
-    }
-
     /// Stores a chunk that Elders sent to it for replication.
-    pub async fn store_for_replication(&mut self, blob: Blob) -> Result<()> {
-        self.chunk_storage.store_for_replication(blob).await
+    pub async fn store_for_replication(
+        &mut self,
+        blob: Blob,
+        msg_id: MessageId,
+    ) -> Result<NodeDuty> {
+        let data_name = *blob.address().name();
+        let result = match self.chunk_storage.store_for_replication(blob).await {
+            Ok(()) => Ok(()),
+            Err(err) => Err(CmdError::Data(convert_to_error_message(err)?)),
+        };
+        Ok(NodeDuty::Send(OutgoingMsg {
+            msg: Message::NodeEvent {
+                event: NodeEvent::ChunkWriteHandled(result),
+                id: MessageId::in_response_to(&msg_id),
+                correlation_id: msg_id,
+            },
+            section_source: false, // sent as single node
+            // Data's metadata section
+            dst: DstLocation::Section(data_name),
+            aggregation: Aggregation::None,
+        }))
     }
 }
 
