@@ -26,7 +26,8 @@ enum Operation {
     },
     Write {
         blob_write: Box<BlobWrite>,
-        origin: EndUser,
+        // Set to None if write was initiated by the section
+        origin: Option<EndUser>,
         targets: BTreeSet<XorName>,
     },
 }
@@ -51,8 +52,8 @@ impl AdultLiveness {
     pub fn new_write(
         &mut self,
         msg_id: MessageId,
+        origin: Option<EndUser>,
         blob_write: BlobWrite,
-        origin: EndUser,
         targets: BTreeSet<XorName>,
     ) -> bool {
         let new_operation = if let Entry::Vacant(entry) = self.ops.entry(msg_id) {
@@ -103,14 +104,14 @@ impl AdultLiveness {
             let message_ids = self.ops.keys().cloned().collect::<Vec<_>>();
             // TODO(after T4): For write operations perhaps we need to write it to a different Adult
             for msg_id in message_ids {
-                self.remove_target(msg_id, name);
+                self.remove_target(msg_id, &name);
             }
         }
         self.recompute_closest_adults();
     }
 
-    pub fn remove_target(&mut self, msg_id: MessageId, name: XorName) {
-        if let Some(count) = self.pending_ops.get_mut(&name) {
+    pub fn remove_target(&mut self, msg_id: MessageId, name: &XorName) {
+        if let Some(count) = self.pending_ops.get_mut(name) {
             let counter = *count;
             if counter > 0 {
                 *count -= 1;
@@ -119,11 +120,11 @@ impl AdultLiveness {
         let complete = if let Some(operation) = self.ops.get_mut(&msg_id) {
             match operation {
                 Operation::Read { targets, .. } => {
-                    let _ = targets.remove(&name);
+                    let _ = targets.remove(name);
                     targets.is_empty()
                 }
                 Operation::Write { targets, .. } => {
-                    let _ = targets.remove(&name);
+                    let _ = targets.remove(name);
                     targets.is_empty()
                 }
             }
@@ -139,11 +140,13 @@ impl AdultLiveness {
         &mut self,
         correlation_id: MessageId,
         src: XorName,
-    ) -> Option<BlobWrite> {
+    ) -> Option<(BlobWrite, Option<EndUser>)> {
         let op = self.ops.get(&correlation_id).cloned();
-        self.remove_target(correlation_id, src);
+        self.remove_target(correlation_id, &src);
         op.and_then(|op| match op {
-            Operation::Write { blob_write, .. } => Some(*blob_write),
+            Operation::Write {
+                blob_write, origin, ..
+            } => Some((*blob_write, origin)),
             Operation::Read { .. } => None,
         })
     }
@@ -154,7 +157,7 @@ impl AdultLiveness {
         src: XorName,
     ) -> Option<(BlobAddress, EndUser)> {
         let op = self.ops.get(&correlation_id).cloned();
-        self.remove_target(correlation_id, src);
+        self.remove_target(correlation_id, &src);
         op.and_then(|op| match op {
             Operation::Read {
                 address, origin, ..
