@@ -16,8 +16,9 @@ mod sequence_storage;
 
 use self::adult_reader::AdultReader;
 use super::node_ops::NodeDuty;
-use crate::{capacity::ChunkHolderDbs, node_ops::NodeDuties, Result};
+use crate::{capacity::AdultsStorageInfo, node_ops::NodeDuties, Result};
 use blob_records::BlobRecords;
+pub(crate) use blob_records::CHUNK_COPY_COUNT;
 use elder_stores::ElderStores;
 use map_storage::MapStorage;
 use register_storage::RegisterStorage;
@@ -28,6 +29,7 @@ use sn_messaging::{
     EndUser, MessageId,
 };
 use std::{
+    collections::BTreeSet,
     fmt::{self, Display, Formatter},
     path::Path,
 };
@@ -47,10 +49,10 @@ impl Metadata {
     pub async fn new(
         path: &Path,
         max_capacity: u64,
-        dbs: ChunkHolderDbs,
+        adult_storage_info: AdultsStorageInfo,
         reader: AdultReader,
     ) -> Result<Self> {
-        let blob_records = BlobRecords::new(dbs, reader);
+        let blob_records = BlobRecords::new(adult_storage_info, reader);
         let map_storage = MapStorage::new(path, max_capacity).await?;
         let sequence_storage = SequenceStorage::new(path, max_capacity).await?;
         let register_storage = RegisterStorage::new(path, max_capacity).await?;
@@ -77,7 +79,7 @@ impl Metadata {
         correlation_id: MessageId,
         result: Result<(), CmdError>,
         src: XorName,
-    ) -> Result<NodeDuty> {
+    ) -> NodeDuties {
         self.elder_stores
             .blob_records_mut()
             .record_adult_write_liveness(correlation_id, result, src)
@@ -96,7 +98,7 @@ impl Metadata {
             .await
     }
 
-    pub async fn retain_members_only(&mut self, members: Vec<XorName>) -> Result<()> {
+    pub async fn retain_members_only(&mut self, members: BTreeSet<XorName>) -> Result<()> {
         self.elder_stores
             .blob_records_mut()
             .retain_members_only(members)
@@ -121,22 +123,11 @@ impl Metadata {
             .await
     }
 
-    // This should be called whenever a node leaves the section. It fetches the list of data that was
-    // previously held by the node and requests the remaining holders to return that chunk to us.
-    // The list of holders is also updated by removing the node that left.
     // When receiving the chunk from remaining holders, we ask new holders to store it.
-    pub async fn remove_and_replicate_chunks(&mut self, node: XorName) -> Result<NodeDuties> {
+    pub async fn republish_chunk(&mut self, data: Blob) -> Result<NodeDuty> {
         self.elder_stores
             .blob_records_mut()
-            .remove_and_replicate_chunks(node)
-            .await
-    }
-
-    // When receiving the chunk from remaining holders, we ask new holders to store it.
-    pub async fn finish_chunk_replication(&mut self, data: Blob) -> Result<NodeDuty> {
-        self.elder_stores
-            .blob_records_mut()
-            .replicate_chunk(data)
+            .republish_chunk(data)
             .await
     }
 
