@@ -7,7 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::{
-    chunk_store::{SequenceChunkStore, UsedSpace},
+    chunk_store::SequenceChunkStore,
     error::convert_to_error_message,
     node_ops::{NodeDuty, OutgoingMsg},
     Error, Result,
@@ -34,8 +34,8 @@ pub(super) struct SequenceStorage {
 }
 
 impl SequenceStorage {
-    pub(super) async fn new(path: &Path, used_space: UsedSpace) -> Result<Self> {
-        let chunks = SequenceChunkStore::new(path, used_space).await?;
+    pub(super) async fn new(path: &Path, max_capacity: u64) -> Result<Self> {
+        let chunks = SequenceChunkStore::new(path, max_capacity).await?;
         Ok(Self { chunks })
     }
 
